==> gradle-src-3.2.1-1-any.pkg.tar.xz: usr/share/java/gradle/src/core/org/gradle/api/internal/tasks/TaskInputFilePropertyBuilderInternal.java <==
/*
 * Copyright 2016 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.gradle.api.internal.tasks;

import org.gradle.api.internal.changedetection.state.SnapshotNormalizationStrategy;
import org.gradle.api.tasks.PathSensitivity;
import org.gradle.api.tasks.TaskInputFilePropertyBuilder;

public interface TaskInputFilePropertyBuilderInternal extends TaskInputFilePropertyBuilder, TaskFilePropertyBuilderInternal {
    @Override
    TaskInputFilePropertyBuilderInternal withSnapshotNormalizationStrategy(SnapshotNormalizationStrategy snapshotNormalizationStrategy);

    @Override
    TaskInputFilePropertyBuilderInternal withPropertyName(String propertyName);

    @Override
    TaskInputFilePropertyBuilderInternal withPathSensitivity(PathSensitivity sensitivity);

    @Override
    TaskInputFilePropertyBuilderInternal skipWhenEmpty();

    @Override
    TaskInputFilePropertyBuilderInternal skipWhenEmpty(boolean skipWhenEmpty);

    @Override
    TaskInputFilePropertyBuilderInternal optional();

    @Override
    TaskInputFilePropertyBuilderInternal optional(boolean optional);

    @Override
    TaskInputFilePropertyBuilderInternal orderSensitive();

    @Override
    TaskInputFilePropertyBuilderInternal orderSensitive(boolean orderSensitive);
}

==> gradle-src-4.2.1-1-any.pkg.tar.xz: usr/share/java/gradle/src/core/org/gradle/api/internal/tasks/TaskInputFilePropertyBuilderInternal.java <==
/*
 * Copyright 2016 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.gradle.api.internal.tasks;

import org.gradle.api.internal.changedetection.state.FileCollectionSnapshotter;
import org.gradle.api.internal.changedetection.state.PathNormalizationStrategy;
import org.gradle.api.tasks.PathSensitivity;
import org.gradle.api.tasks.TaskInputFilePropertyBuilder;

public interface TaskInputFilePropertyBuilderInternal extends TaskInputFilePropertyBuilder, TaskFilePropertyBuilderInternal {
    @Override
    TaskInputFilePropertyBuilderInternal withPathNormalizationStrategy(PathNormalizationStrategy pathNormalizationStrategy);

    @Override
    TaskInputFilePropertyBuilderInternal withSnapshotter(Class<? extends FileCollectionSnapshotter> snapshotter);

    @Override
    TaskInputFilePropertyBuilderInternal withPropertyName(String propertyName);

    @Override
    TaskInputFilePropertyBuilderInternal withPathSensitivity(PathSensitivity sensitivity);

    @Override
    TaskInputFilePropertyBuilderInternal skipWhenEmpty();

    @Override
    TaskInputFilePropertyBuilderInternal skipWhenEmpty(boolean skipWhenEmpty);

    @Override
    TaskInputFilePropertyBuilderInternal optional();

    @Override
    TaskInputFilePropertyBuilderInternal optional(boolean optional);
}
